# sigfox-api-client
 # API overview Sigfox API is used to integrate with the Sigfox platform.  The API uses the HTTP protocol, following the REST principles (POST, GET, DELETE, PUT requests). The API endpoints accept and return data in the JSON format, with the corresponding \"application/json\" content type header.  The Sigfox API access differs for every API User based on their profile. If you already have a Sigfox account, you can retrieve the API Documentation customized for your API User directly in json or yaml format. The “how to” procedure is detailed in the [API Documentation](https://support.sigfox.com/docs/api-documentation) article.  The PUT request is the only request used to edit an existing entity. You don't need to specify each value. If a property is not present in the request, it won't be processed and updated. To remove an optional property, it must be filled in the request with the explicit value NULL. If a property has no value, it won't appear in the result of a GET request.  # Authentication and security Sigfox API is only accessible using HTTPS, and all API endpoints require authentication credentials (API user login and password). An API User is associated to a group with given profiles. You can view and manage your API User in the [Sigfox Portal](https://backend.sigfox.com/auth/login).  If you need an API User, follow the [API credential creation](https://support.sigfox.com/docs/api-credential-creation) procedure.  Your API User must remain private. Should the API credentials be compromised, new ones can be generated at any moment, invalidating the previous ones. CORS and JSONP are intentionally unsupported. CORS and JSONP JavaScript techniques tends to expose your credentials to your users. If you really need to call Sigfox API from JavaScript in the browser, you must set a reverse proxy on your website. Be careful not to use proxy for all requests to Sigfox OSS but to only select the relevant ones.  <!-- ReDoc-Inject: <security-definitions> -->  # Usage limits All Sigfox API endpoints are using the same underlying technology that powers the core Sigfox Platform. For Cloud efficiency and security reasons, Sigfox is moving a step forward on API rate limiting, by setting upper bounds for some API endpoints. Please note that a new HTTP response will be returned in case of rate exceeded : “HTTP 429: too many requests”.  For more information check [API Rate limiting](https://support.sigfox.com/docs/api-rate-limiting) policy. Sigfox reserves the right to modify these limits without notice.  # Versioning  Sigfox API supports versioning of its endpoints through a version suffix in the endpoint URL. This suffix has the following format: \"vX\", where X is the version number. For example: v2/device.  All requests must include the version suffix in the endpoint URL.  Any new backwards-incompatible change will be released in a new version.   Read the [API versioning management](https://storage.sbg1.cloud.ovh.net/v1/AUTH_669d7dfced0b44518cb186841d7cbd75/prod_docs/55746591-API_Versioning_management.pdf) to learn more about it.  # Paging  Some API requests will return a list of data. If the list is longer than the set limit, the items will be retrieved via multiple requests. The paging section in the response will specify a URL for the next request.  Keep in mind rate limiting policy to manage your requests.  You can use the limit parameter to limit the number of items to be returned, between 1 and 100 (default). The offset parameter is used to specify a number of items to skip.  # Errors  Sigfox API uses conventional HTTP response codes to indicate the success or failure of an API request.  Codes in the 2xx range indicate success.  Codes in the 4xx range indicate an error that failed given the information provided (e.g. a required parameter missing, a resource was not found, etc.). Often the response will also include a message explaining the error.  Codes in the 5xx range indicate an error with servers.   For more information please refer to the [Response code article](https://support.sigfox.com/docs/api-response-code-references). 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://support.sigfox.com](https://support.sigfox.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import sigfox_api_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import sigfox_api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import sigfox_api_client
from sigfox_api_client.rest import ApiException
from pprint import pprint
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
body = sigfox_api_client.ProfileIds() # ProfileIds | The API profile to update
id = 'id_example' # str | The API user identifier

try:
    # Associate profiles to an API user.
    api_instance.add_profile_to_api_user(body, id)
except ApiException as e:
    print("Exception when calling ApiUsersApi->add_profile_to_api_user: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
body = sigfox_api_client.ApiUserCreation() # ApiUserCreation | 

try:
    # Create an API user
    api_response = api_instance.create_api_user(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiUsersApi->create_api_user: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
id = 'id_example' # str | The API user identifier

try:
    # Delete an API user
    api_instance.delete_api_user(id)
except ApiException as e:
    print("Exception when calling ApiUsersApi->delete_api_user: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
id = 'id_example' # str | The API user identifier
profile_id = 'profile_id_example' # str | The profile identifier

try:
    # Delete a profile to a given API user.
    api_instance.delete_profile_of_api_user(id, profile_id)
except ApiException as e:
    print("Exception when calling ApiUsersApi->delete_profile_of_api_user: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
id = 'id_example' # str | The API user identifier
fields = 'fields_example' # str | Defines the other available fields to be returned in the response.  (optional)

try:
    # Retrieve information about an API user
    api_response = api_instance.get_api_user(id, fields=fields)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiUsersApi->get_api_user: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
fields = 'fields_example' # str | Defines the other available fields to be returned in the response.  (optional)
profile_id = 'profile_id_example' # str | Searches for API users with the given profile (optional)
group_ids = ['group_ids_example'] # list[str] | Searches for API users who are attached to the given groups (optional)
limit = 56 # int | Defines the maximum number of items to return (optional)
offset = 56 # int | Defines the number of items to skip (optional)

try:
    # Retrieve a list of API users
    api_response = api_instance.list_api_users(fields=fields, profile_id=profile_id, group_ids=group_ids, limit=limit, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiUsersApi->list_api_users: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
id = 'id_example' # str | The API user identifier

try:
    # Generate a new password for an API user
    api_response = api_instance.renew_credential(id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ApiUsersApi->renew_credential: %s\n" % e)
# Configure HTTP basic authorization: basicAuth
configuration = sigfox_api_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = sigfox_api_client.ApiUsersApi(sigfox_api_client.ApiClient(configuration))
body = sigfox_api_client.ApiUserEdition() # ApiUserEdition | The information to update
id = 'id_example' # str | The API user identifier

try:
    # Update an API user
    api_instance.update_api_user(body, id)
except ApiException as e:
    print("Exception when calling ApiUsersApi->update_api_user: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.sigfox.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiUsersApi* | [**add_profile_to_api_user**](docs/ApiUsersApi.md#add_profile_to_api_user) | **PUT** /api-users/{id}/profiles | Associate profiles to an API user.
*ApiUsersApi* | [**create_api_user**](docs/ApiUsersApi.md#create_api_user) | **POST** /api-users/ | Create an API user
*ApiUsersApi* | [**delete_api_user**](docs/ApiUsersApi.md#delete_api_user) | **DELETE** /api-users/{id} | Delete an API user
*ApiUsersApi* | [**delete_profile_of_api_user**](docs/ApiUsersApi.md#delete_profile_of_api_user) | **DELETE** /api-users/{id}/profiles/{profileId} | Delete a profile to a given API user.
*ApiUsersApi* | [**get_api_user**](docs/ApiUsersApi.md#get_api_user) | **GET** /api-users/{id} | Retrieve information about an API user
*ApiUsersApi* | [**list_api_users**](docs/ApiUsersApi.md#list_api_users) | **GET** /api-users/ | Retrieve a list of API users
*ApiUsersApi* | [**renew_credential**](docs/ApiUsersApi.md#renew_credential) | **PUT** /api-users/{id}/renew-credential | Generate a new password for an API user
*ApiUsersApi* | [**update_api_user**](docs/ApiUsersApi.md#update_api_user) | **PUT** /api-users/{id} | Update an API user
*ContractInfosApi* | [**contract_bulk_restart**](docs/ContractInfosApi.md#contract_bulk_restart) | **POST** /contract-infos/{id}/bulk/restart | Create a job to restart the devices associated to a contract
*ContractInfosApi* | [**device_list**](docs/ContractInfosApi.md#device_list) | **GET** /contract-infos/{id}/devices | Retrieve the list of devices having a token on the specified contract
*ContractInfosApi* | [**get_contract_bulk_restart_job**](docs/ContractInfosApi.md#get_contract_bulk_restart_job) | **GET** /contract-infos/bulk/restart/{jobId} | Retrieve a contract async job status for restart action
*ContractInfosApi* | [**get_contract_info**](docs/ContractInfosApi.md#get_contract_info) | **GET** /contract-infos/{id} | Retrieve information about a contract
*ContractInfosApi* | [**list_contract_infos**](docs/ContractInfosApi.md#list_contract_infos) | **GET** /contract-infos/ | Retrieve a list of contracts
*CoveragesApi* | [**coverages_global_predictions_get**](docs/CoveragesApi.md#coverages_global_predictions_get) | **GET** /coverages/global/predictions | Retrieve coverage predictions for any location.
*CoveragesApi* | [**coverages_global_predictions_post**](docs/CoveragesApi.md#coverages_global_predictions_post) | **POST** /coverages/global/predictions | Retrieve coverage predictions for any batch of locations
*CoveragesApi* | [**coverages_operators_redundancy_get**](docs/CoveragesApi.md#coverages_operators_redundancy_get) | **GET** /coverages/operators/redundancy | Retrieve coverage redundancy for an operator.
*DeviceTypesApi* | [**create_callback**](docs/DeviceTypesApi.md#create_callback) | **POST** /device-types/{id}/callbacks | Create a callback
*DeviceTypesApi* | [**create_device_type**](docs/DeviceTypesApi.md#create_device_type) | **POST** /device-types/ | Create a device type
*DeviceTypesApi* | [**delete_callback**](docs/DeviceTypesApi.md#delete_callback) | **DELETE** /device-types/{id}/callbacks/{callbackId} | Delete a callback
*DeviceTypesApi* | [**device_type_bulk_restart**](docs/DeviceTypesApi.md#device_type_bulk_restart) | **POST** /device-types/{id}/bulk/restart | Restart the devices of a device type
*DeviceTypesApi* | [**device_types_delete**](docs/DeviceTypesApi.md#device_types_delete) | **DELETE** /device-types/{id} | Delete a device type
*DeviceTypesApi* | [**device_types_seq_number_disengage**](docs/DeviceTypesApi.md#device_types_seq_number_disengage) | **PUT** /device-types/{id}/disengage | Disengage sequence number check for the next message
*DeviceTypesApi* | [**enable_callback**](docs/DeviceTypesApi.md#enable_callback) | **PUT** /device-types/{id}/callbacks/{callbackId}/enable | Enable or disable a callback
*DeviceTypesApi* | [**enable_downlink_callback**](docs/DeviceTypesApi.md#enable_downlink_callback) | **PUT** /device-types/{id}/callbacks/{callbackId}/downlink | Selects a downlink callback
*DeviceTypesApi* | [**get_callback_messages_error_list_for_device_type**](docs/DeviceTypesApi.md#get_callback_messages_error_list_for_device_type) | **GET** /device-types/{id}/callbacks-not-delivered | Retrieve a list of callback errors
*DeviceTypesApi* | [**get_device_messages_list_for_device_type**](docs/DeviceTypesApi.md#get_device_messages_list_for_device_type) | **GET** /device-types/{id}/messages | Retrieve a list of messages
*DeviceTypesApi* | [**get_device_type**](docs/DeviceTypesApi.md#get_device_type) | **GET** /device-types/{id} | Retrieve information about a device type
*DeviceTypesApi* | [**get_device_type_bulk_restart_job**](docs/DeviceTypesApi.md#get_device_type_bulk_restart_job) | **GET** /device-types/bulk/restart/{jobId} | Retrieve the device type async job status for restart action
*DeviceTypesApi* | [**list_callbacks**](docs/DeviceTypesApi.md#list_callbacks) | **GET** /device-types/{id}/callbacks | Retrieve a list of callbacks
*DeviceTypesApi* | [**list_device_types**](docs/DeviceTypesApi.md#list_device_types) | **GET** /device-types/ | Retrieve a list of device types
*DeviceTypesApi* | [**update_callback**](docs/DeviceTypesApi.md#update_callback) | **PUT** /device-types/{id}/callbacks/{callbackId} | Update a callback
*DeviceTypesApi* | [**update_device_type**](docs/DeviceTypesApi.md#update_device_type) | **PUT** /device-types/{id} | Update a device type
*DevicesApi* | [**create_bulk_device**](docs/DevicesApi.md#create_bulk_device) | **POST** /devices/bulk | Create multiple devices
*DevicesApi* | [**create_device**](docs/DevicesApi.md#create_device) | **POST** /devices/ | Create a device
*DevicesApi* | [**delete_device**](docs/DevicesApi.md#delete_device) | **DELETE** /devices/{id} | Delete a device
*DevicesApi* | [**device_bulk_edit_async**](docs/DevicesApi.md#device_bulk_edit_async) | **PUT** /devices/bulk | Update multiple devices
*DevicesApi* | [**device_bulk_transfer**](docs/DevicesApi.md#device_bulk_transfer) | **POST** /devices/bulk/transfer | Transfer multiple devices to another device type
*DevicesApi* | [**device_bulk_unsubscribe**](docs/DevicesApi.md#device_bulk_unsubscribe) | **POST** /devices/bulk/unsubscribe | Unsubscribe multiple devices
*DevicesApi* | [**device_seq_number_disengage**](docs/DevicesApi.md#device_seq_number_disengage) | **POST** /devices/{id}/disengage | Disengage sequence number check for the next message
*DevicesApi* | [**devices_bulk_replace**](docs/DevicesApi.md#devices_bulk_replace) | **POST** /devices/bulk/replace | Replace multiple devices
*DevicesApi* | [**devices_bulk_restart**](docs/DevicesApi.md#devices_bulk_restart) | **POST** /devices/bulk/restart | Restart multiple devices
*DevicesApi* | [**devices_bulk_resume**](docs/DevicesApi.md#devices_bulk_resume) | **POST** /devices/bulk/resume | Resume multiple devices
*DevicesApi* | [**devices_bulk_suspend**](docs/DevicesApi.md#devices_bulk_suspend) | **POST** /devices/bulk/suspend | Suspend multiple devices
*DevicesApi* | [**devices_id_consumption_year_get**](docs/DevicesApi.md#devices_id_consumption_year_get) | **GET** /devices/{id}/consumption/{year} | Retrieve a device&#x27;s consumption for a year
*DevicesApi* | [**devices_id_consumption_year_month_get**](docs/DevicesApi.md#devices_id_consumption_year_month_get) | **GET** /devices/{id}/consumption/{year}/{month} | Get a Device&#x27;s consumption for a given month
*DevicesApi* | [**devices_id_messages_metric_get**](docs/DevicesApi.md#devices_id_messages_metric_get) | **GET** /devices/{id}/messages/metric | Retreive the number of messages
*DevicesApi* | [**get_bulk_job_for_device**](docs/DevicesApi.md#get_bulk_job_for_device) | **GET** /devices/bulk/{jobId} | Retrieve the status of a job
*DevicesApi* | [**get_bulk_restart_job**](docs/DevicesApi.md#get_bulk_restart_job) | **GET** /devices/bulk/restart/{jobId} | Retrieve the async job status for a restart action.
*DevicesApi* | [**get_bulk_resume_job**](docs/DevicesApi.md#get_bulk_resume_job) | **GET** /devices/bulk/resume/{jobId} | Retrieve the status of a resume job
*DevicesApi* | [**get_bulk_suspend_job**](docs/DevicesApi.md#get_bulk_suspend_job) | **GET** /devices/bulk/suspend/{jobId} | Retrieve the status of a suspend job
*DevicesApi* | [**get_callback_messages_error_list_for_device**](docs/DevicesApi.md#get_callback_messages_error_list_for_device) | **GET** /devices/{id}/callbacks-not-delivered | Retrieve a list of undelivered callbacks
*DevicesApi* | [**get_device**](docs/DevicesApi.md#get_device) | **GET** /devices/{id} | Retrieve information about a device
*DevicesApi* | [**get_device_locations_list**](docs/DevicesApi.md#get_device_locations_list) | **GET** /devices/{id}/locations | Retrieve the locations of a device
*DevicesApi* | [**get_device_messages_list_for_device**](docs/DevicesApi.md#get_device_messages_list_for_device) | **GET** /devices/{id}/messages | Retrieve a list of messages
*DevicesApi* | [**get_device_unsubscribe_job**](docs/DevicesApi.md#get_device_unsubscribe_job) | **GET** /devices/bulk/unsubscribe/{jobId} | Retrieve the async job status for an unsubscribe action.
*DevicesApi* | [**get_modem_certificate_info**](docs/DevicesApi.md#get_modem_certificate_info) | **GET** /devices/{id}/certificate/modem | Retrieve the modem certificate associated with a device
*DevicesApi* | [**get_product_certificate_info**](docs/DevicesApi.md#get_product_certificate_info) | **GET** /devices/{id}/certificate/product | Retrieve the product certificate associated with a device
*DevicesApi* | [**get_product_certificate_info_with_pac**](docs/DevicesApi.md#get_product_certificate_info_with_pac) | **GET** /devices/{id}/product-certificate | Retrieve the product certificate associated with a device ID and PAC
*DevicesApi* | [**list_devices**](docs/DevicesApi.md#list_devices) | **GET** /devices/ | Retrieve a list of devices
*DevicesApi* | [**unsubscribe**](docs/DevicesApi.md#unsubscribe) | **PUT** /devices/{id}/unsubscribe | Unsubscribe a device
*DevicesApi* | [**update_device**](docs/DevicesApi.md#update_device) | **PUT** /devices/{id} | Update a device
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /groups/ | Create a group
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /groups/{id} | Delete a group
*GroupsApi* | [**get_callback_messages_error_list_for_group**](docs/GroupsApi.md#get_callback_messages_error_list_for_group) | **GET** /groups/{id}/callbacks-not-delivered | Retrieve a list of undelivered callbacks
*GroupsApi* | [**get_group**](docs/GroupsApi.md#get_group) | **GET** /groups/{id} | Retrieve information about a group
*GroupsApi* | [**list_geolocation_payload**](docs/GroupsApi.md#list_geolocation_payload) | **GET** /groups/{id}/geoloc-payloads | Retrieve a list of geolocation payload
*GroupsApi* | [**list_groups**](docs/GroupsApi.md#list_groups) | **GET** /groups/ | Retrieve a list of groups according to visibility permissions and request filters.
*GroupsApi* | [**update_group**](docs/GroupsApi.md#update_group) | **PUT** /groups/{id} | Update a group
*ProfilesApi* | [**listprofiles**](docs/ProfilesApi.md#listprofiles) | **GET** /profiles/ | Retrieve a list of profiles
*TilesApi* | [**kmz_create_monarch**](docs/TilesApi.md#kmz_create_monarch) | **POST** /tiles/monarch/kmz | Compute Sigfox Monarch coverage in order to allow export as kmz file
*TilesApi* | [**kmz_create_public_operator**](docs/TilesApi.md#kmz_create_public_operator) | **POST** /tiles/public-operator/{groupId}/kmz | Compute Sigfox Public operator public coverage in order to allow export as kmz file
*TilesApi* | [**kmz_file_monarch**](docs/TilesApi.md#kmz_file_monarch) | **GET** /tiles/monarch/kmz/{jobId}/tiles.kmz | Retrieve Sigfox Monarch coverage kmz file
*TilesApi* | [**kmz_file_public_coverage**](docs/TilesApi.md#kmz_file_public_coverage) | **GET** /tiles/public-coverage/kmz/tiles.kmz | Retrieve Sigfox public coverage kmz file
*TilesApi* | [**kmz_file_public_operator**](docs/TilesApi.md#kmz_file_public_operator) | **GET** /tiles/public-operator/{groupId}/kmz/{jobId}/tiles.kmz | Retrieve Sigfox public Operator coverage kmz file
*TilesApi* | [**kmz_status_monarch**](docs/TilesApi.md#kmz_status_monarch) | **GET** /tiles/monarch/kmz/{jobId} | Retrieve Sigfox Monarch coverage kmz computed job results
*TilesApi* | [**kmz_status_public_operator**](docs/TilesApi.md#kmz_status_public_operator) | **GET** /tiles/public-operator/{groupId}/kmz/{jobId} | Retrieve Sigfox public Operator coverage kmz computed job results
*TilesApi* | [**tiles_monarch_get**](docs/TilesApi.md#tiles_monarch_get) | **GET** /tiles/monarch | Retrieve the information needed to display Sigfox Monarch service coverage.
*TilesApi* | [**tiles_public_coverage_get**](docs/TilesApi.md#tiles_public_coverage_get) | **GET** /tiles/public-coverage | Retrieve the information needed to display Sigfox public coverage.
*UsersApi* | [**add_user_roles**](docs/UsersApi.md#add_user_roles) | **PUT** /users/{id}/profiles | add user roles to a user
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /users/ | Create a user
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /users/{id} | Delete a user
*UsersApi* | [**delete_user_role**](docs/UsersApi.md#delete_user_role) | **DELETE** /users/{id}/profiles/{profileId} | Delete profiles or a given profile associated to the groupId
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /users/{id} | Retrieve information about a user
*UsersApi* | [**list_users**](docs/UsersApi.md#list_users) | **GET** /users/ | Retrieve a list of users according to visibility permissions and request filters
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /users/{id} | Update a user

## Documentation For Models

 - [ActionJob](docs/ActionJob.md)
 - [Antenna](docs/Antenna.md)
 - [ApiUser](docs/ApiUser.md)
 - [ApiUserCreation](docs/ApiUserCreation.md)
 - [ApiUserEdition](docs/ApiUserEdition.md)
 - [AsynchronousDeviceCreationJob](docs/AsynchronousDeviceCreationJob.md)
 - [AsynchronousDeviceEditionJob](docs/AsynchronousDeviceEditionJob.md)
 - [AsynchronousDeviceReplacementJob](docs/AsynchronousDeviceReplacementJob.md)
 - [AsynchronousDeviceTransferJob](docs/AsynchronousDeviceTransferJob.md)
 - [BaseContact](docs/BaseContact.md)
 - [BaseConvention](docs/BaseConvention.md)
 - [BaseDeviceType](docs/BaseDeviceType.md)
 - [BaseGeolocation](docs/BaseGeolocation.md)
 - [BaseHost](docs/BaseHost.md)
 - [BaseIntervention](docs/BaseIntervention.md)
 - [BaseMaintenance](docs/BaseMaintenance.md)
 - [BaseProvider](docs/BaseProvider.md)
 - [BaseResponse](docs/BaseResponse.md)
 - [BaseSite](docs/BaseSite.md)
 - [BaseStation](docs/BaseStation.md)
 - [Basic](docs/Basic.md)
 - [BasicCreate](docs/BasicCreate.md)
 - [BasicUpdate](docs/BasicUpdate.md)
 - [BatchUrlCallback](docs/BatchUrlCallback.md)
 - [BillableGroup](docs/BillableGroup.md)
 - [Bounds](docs/Bounds.md)
 - [BulkDeviceAsynchronousRequest](docs/BulkDeviceAsynchronousRequest.md)
 - [BulkUnsubscribe](docs/BulkUnsubscribe.md)
 - [Callback](docs/Callback.md)
 - [CallbackEmail](docs/CallbackEmail.md)
 - [CallbackHTTP](docs/CallbackHTTP.md)
 - [CallbackMedium](docs/CallbackMedium.md)
 - [CbStatus](docs/CbStatus.md)
 - [CellularConnectivityBase](docs/CellularConnectivityBase.md)
 - [CellularConnectivityForBs](docs/CellularConnectivityForBs.md)
 - [CellularConnectivityForGroup](docs/CellularConnectivityForGroup.md)
 - [CellularConnectivityUpdate](docs/CellularConnectivityUpdate.md)
 - [Certificate](docs/Certificate.md)
 - [CertificateUpdate](docs/CertificateUpdate.md)
 - [Channel](docs/Channel.md)
 - [ChannelCreate](docs/ChannelCreate.md)
 - [ChannelUpdate](docs/ChannelUpdate.md)
 - [CommonApiUser](docs/CommonApiUser.md)
 - [CommonCertificate](docs/CommonCertificate.md)
 - [CommonContractInfo](docs/CommonContractInfo.md)
 - [CommonDevice](docs/CommonDevice.md)
 - [CommonGroupCreate](docs/CommonGroupCreate.md)
 - [CommonGroupUpdate](docs/CommonGroupUpdate.md)
 - [CommonRole](docs/CommonRole.md)
 - [CommonUser](docs/CommonUser.md)
 - [ComputedLocation](docs/ComputedLocation.md)
 - [Contact](docs/Contact.md)
 - [ContractId](docs/ContractId.md)
 - [ContractInfo](docs/ContractInfo.md)
 - [ContractInfoCreate](docs/ContractInfoCreate.md)
 - [ContractInfoUpdate](docs/ContractInfoUpdate.md)
 - [Convention](docs/Convention.md)
 - [CreateBatchUrlCallback](docs/CreateBatchUrlCallback.md)
 - [CreateCallback](docs/CreateCallback.md)
 - [CreateEmailCallback](docs/CreateEmailCallback.md)
 - [CreateResponse](docs/CreateResponse.md)
 - [CreateUrlCallback](docs/CreateUrlCallback.md)
 - [DIST](docs/DIST.md)
 - [DISTCreate](docs/DISTCreate.md)
 - [DISTUpdate](docs/DISTUpdate.md)
 - [Device](docs/Device.md)
 - [DeviceActionJob](docs/DeviceActionJob.md)
 - [DeviceConsumption](docs/DeviceConsumption.md)
 - [DeviceCreationJob](docs/DeviceCreationJob.md)
 - [DeviceEditionBulk](docs/DeviceEditionBulk.md)
 - [DeviceLocation](docs/DeviceLocation.md)
 - [DeviceMessage](docs/DeviceMessage.md)
 - [DeviceType](docs/DeviceType.md)
 - [DeviceTypeCreate](docs/DeviceTypeCreate.md)
 - [DeviceTypeUpdate](docs/DeviceTypeUpdate.md)
 - [DeviceUpdateJob](docs/DeviceUpdateJob.md)
 - [DownlinkAnswerStatus](docs/DownlinkAnswerStatus.md)
 - [EmailCallback](docs/EmailCallback.md)
 - [ErrorContent](docs/ErrorContent.md)
 - [ErrorMessages](docs/ErrorMessages.md)
 - [EthernetConnectivityBase](docs/EthernetConnectivityBase.md)
 - [EthernetConnectivityForBs](docs/EthernetConnectivityForBs.md)
 - [EthernetConnectivityForGroup](docs/EthernetConnectivityForGroup.md)
 - [EthernetConnectivityUpdate](docs/EthernetConnectivityUpdate.md)
 - [GeolocPayloadConfig](docs/GeolocPayloadConfig.md)
 - [GlobalCoverageRequest](docs/GlobalCoverageRequest.md)
 - [GlobalCoverageResponse](docs/GlobalCoverageResponse.md)
 - [Group](docs/Group.md)
 - [Host](docs/Host.md)
 - [HostCreation](docs/HostCreation.md)
 - [InternetSubscription](docs/InternetSubscription.md)
 - [Intervention](docs/Intervention.md)
 - [JobError](docs/JobError.md)
 - [KmzCreatePublicRequest](docs/KmzCreatePublicRequest.md)
 - [KmzStatusResponse](docs/KmzStatusResponse.md)
 - [LatLng](docs/LatLng.md)
 - [Location](docs/Location.md)
 - [LocationWithStatus](docs/LocationWithStatus.md)
 - [Maintenance](docs/Maintenance.md)
 - [MinBaseStation](docs/MinBaseStation.md)
 - [MinContact](docs/MinContact.md)
 - [MinContractInfo](docs/MinContractInfo.md)
 - [MinDeviceType](docs/MinDeviceType.md)
 - [MinGroup](docs/MinGroup.md)
 - [MinHost](docs/MinHost.md)
 - [MinHwFamily](docs/MinHwFamily.md)
 - [MinMaintenance](docs/MinMaintenance.md)
 - [MinMetaRole](docs/MinMetaRole.md)
 - [MinPerm](docs/MinPerm.md)
 - [MinProfile](docs/MinProfile.md)
 - [MinProvider](docs/MinProvider.md)
 - [MinRole](docs/MinRole.md)
 - [MinSite](docs/MinSite.md)
 - [ModemCertificate](docs/ModemCertificate.md)
 - [ModemCertificateRadioConfiguration](docs/ModemCertificateRadioConfiguration.md)
 - [NIP](docs/NIP.md)
 - [NIPCreate](docs/NIPCreate.md)
 - [NIPUpdate](docs/NIPUpdate.md)
 - [Paging](docs/Paging.md)
 - [Partner](docs/Partner.md)
 - [PartnerCreate](docs/PartnerCreate.md)
 - [PartnerUpdate](docs/PartnerUpdate.md)
 - [Partners](docs/Partners.md)
 - [PartnersCreate](docs/PartnersCreate.md)
 - [PartnersUpdate](docs/PartnersUpdate.md)
 - [ProductCertificate](docs/ProductCertificate.md)
 - [ProductCertificateRadioConfiguration](docs/ProductCertificateRadioConfiguration.md)
 - [ProductCertificateWithPacResponse](docs/ProductCertificateWithPacResponse.md)
 - [Profile](docs/Profile.md)
 - [ProfileIds](docs/ProfileIds.md)
 - [Provider](docs/Provider.md)
 - [ProviderCreation](docs/ProviderCreation.md)
 - [RadioCertificate](docs/RadioCertificate.md)
 - [RadioConfiguration](docs/RadioConfiguration.md)
 - [RedundancyResponse](docs/RedundancyResponse.md)
 - [RegistrationJob](docs/RegistrationJob.md)
 - [RegistrationJobStatus](docs/RegistrationJobStatus.md)
 - [ReplaceResponse](docs/ReplaceResponse.md)
 - [Rinfo](docs/Rinfo.md)
 - [Role](docs/Role.md)
 - [RoleCreate](docs/RoleCreate.md)
 - [SO](docs/SO.md)
 - [SOCreate](docs/SOCreate.md)
 - [SOUpdate](docs/SOUpdate.md)
 - [SVNO](docs/SVNO.md)
 - [SVNOCreate](docs/SVNOCreate.md)
 - [SVNOUpdate](docs/SVNOUpdate.md)
 - [SingleDeviceFields](docs/SingleDeviceFields.md)
 - [Site](docs/Site.md)
 - [Sites](docs/Sites.md)
 - [Starter](docs/Starter.md)
 - [StarterCreate](docs/StarterCreate.md)
 - [StarterUpdate](docs/StarterUpdate.md)
 - [TilesResponse](docs/TilesResponse.md)
 - [Token](docs/Token.md)
 - [TokenUnsubscribe](docs/TokenUnsubscribe.md)
 - [UpdateCallback](docs/UpdateCallback.md)
 - [UpdateEmailCallback](docs/UpdateEmailCallback.md)
 - [UpdateResponse](docs/UpdateResponse.md)
 - [UpdateUrlCallback](docs/UpdateUrlCallback.md)
 - [UpdatebatchUrlCallback](docs/UpdatebatchUrlCallback.md)
 - [UrlCallback](docs/UrlCallback.md)
 - [User](docs/User.md)
 - [UserCreation](docs/UserCreation.md)
 - [UserRole](docs/UserRole.md)
 - [UserUpdate](docs/UserUpdate.md)

## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## Author


